==> nextcloud-app-mail-1.1.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_CN.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "邮件",
    "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
    "Updating account failed: " : "更新账号失败：",
    "Creating account failed: " : "创建账号失败：",
    "Embedded message %s" : "嵌入式消息 %s",
    "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
    "Auto" : "自动",
    "Name" : "姓名",
    "Mail Address" : "邮箱",
    "Password" : "密码",
    "Manual" : "手动",
    "IMAP Settings" : "IMAP 设置",
    "IMAP Host" : "IMAP 主机",
    "IMAP Security" : "IMAP 安全",
    "None" : "无",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Settings" : "SMTP 设置",
    "SMTP Host" : "SMTP 主机",
    "SMTP Security" : "SMTP 安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Connect" : "连接",
    "Add mail account" : "添加邮件账号",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
    "Register as application for mail links" : "注册为邮件链接应用",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
    "From" : "发件人",
    "Select account" : "选择账号",
    "To" : "收件人",
    "Contact or email address …" : "联系人或邮箱地址...",
    "+ CC/BCC" : "+ 抄送/密送",
    "CC" : "抄送",
    "No contacts found." : "未找到联系人。",
    "BCC" : "密送",
    "Subject" : "主题",
    "Subject …" : "标题...",
    "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
    "Write message …" : "编写消息...",
    "Saving draft …" : "正在保存草稿 …",
    "Draft saved" : "草稿已保存",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Enable formatting" : "启用格式化",
    "Uploading attachments …" : "正在上传附件…",
    "Sending …" : "正在发送…",
    "Error sending your message" : "发送您的消息时出错",
    "Go back" : "后退",
    "Retry" : "重试",
    "Message sent!" : "消息已发送！",
    "Reply sent!" : "回复已发送！",
    "Write another message" : "再写一条消息",
    "Send" : "发送",
    "Uploading {percent}% …" : "正在上传 {percent}% …",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "Writing mode" : "编写模式",
    "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
    "Plain text" : "纯文本",
    "Rich text" : "富文本",
    "No messages in this folder" : "该文件夹内没有消息",
    "Draft: " : "草稿: ",
    "Mark read" : "标记为已读",
    "Mark unread" : "标记为未读",
    "Delete" : "删除",
    "Blind copy recipients only" : "仅向收件人发送无信头副本",
    "Report this bug" : "报告此问题",
    "Loading messages" : "正在加载消息",
    "Not found" : "没有找到",
    "Reply" : "回复",
    "Reply to sender only" : "只回复发送者",
    "Forward" : "转发",
    "Could not load your message" : "无法加载您的消息",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”",
    "Embedded message" : "嵌入式消息",
    "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
    "Save all to Files" : "全部保存到文件",
    "Choose a folder to store the attachments in" : "选择附件保存的目录",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images from this\tsender" : "显示此发件人的图片",
    "New message" : "新建消息",
    "Settings" : "设置",
    "Edit account" : "编辑账号",
    "Add folder" : "添加文件夹",
    "Move Up" : "上移",
    "Move down" : "下移",
    "Delete account" : "删除账号",
    "Show all folders" : "显示全部文件夹",
    "Collapse folders" : "折叠文件夹",
    "Mark all as read" : "标记所有为已读",
    "Mark all messages of this folder as read" : "将此文件夹中的所有消息都标记为已读",
    "Add subfolder" : "添加子文件夹",
    "Loading …" : "正在加载...",
    "_{total} message_::_{total} messages_" : ["{total} 条消息"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["{unread} 条未读，一共 {total} 条"],
    "Could not load your draft" : "无法加载您的草稿",
    "Could not load original message" : "无法加载初始消息",
    "No message selected" : "没有选择消息",
    "Signature" : "签名",
    "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
    "Signature …" : "签名...",
    "Save signature" : "保存签名",
    "Import into {calendar}" : "导入到 {calendar}",
    "Event imported into {calendar}" : "事件导入到 {calendar}",
    "Could not create event" : "无法建立事件",
    "Airplane" : "飞机",
    "Reservation {id}" : "预订 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} 航班从 {depAirport} 飞往 {arrAirport}",
    "Train" : "火车",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 从 {depStation} 到 {arrStation}",
    "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
    "Mail app" : "邮件应用",
    "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
    "Email: {email}" : "电子邮件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
    "Provision an account for every user" : "为每个用户设置一个账号",
    "General" : "常规",
    "Email address" : "Email 地址",
    "IMAP" : "IMAP",
    "User" : "用户",
    "Host" : "主机",
    "Port" : "端口",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
    "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
    "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
    "Account settings" : "账号设置",
    "Change name" : "更改名称",
    "Mail server" : "邮件服务器",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Search" : "搜索",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账号",
    "Unexpected error during account creation" : "创建账号时发生意外错误",
    "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "Error loading message" : "载入消息时发生错误",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此网页，您可以返回到<a href=\"%s\">邮件</a>应用。",
    "Continue to %s" : "继续 %s"
},
"nplurals=1; plural=0;");

==> nextcloud-app-mail-1.3.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/zh_CN.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "邮件",
    "Auto detect failed. Please use manual mode." : "自动检测失败，请使用手动模式。",
    "Updating account failed: " : "更新账号失败：",
    "Creating account failed: " : "创建账号失败：",
    "Embedded message %s" : "嵌入式消息 %s",
    "💌 A mail app for Nextcloud" : "💌 Nextcloud 上的一款邮件应用",
    "**💌 A mail app for Nextcloud**\n\n- **🚀 Integration with other Nextcloud apps!** Currently Contacts, Calendar & Files – more to come.\n- **📥 Multiple mail accounts!** Personal and company account? No problem, and a nice unified inbox. Connect any IMAP account.\n- **🔒 Send & receive encrypted mails!** Using the great [Mailvelope](https://mailvelope.com) browser extension.\n- **🙈 We’re not reinventing the wheel!** Based on the great [Horde](http://horde.org) libraries.\n- **📬 Want to host your own mail server?** We don’t have to reimplement this as you could set up [Mail-in-a-Box](https://mailinabox.email)!" : "**💌 Nextcloud 上的一款邮件应用**\n\n- **🚀 与其他 Nextcloud 应用集成！** 当前已集成联系人、日历和文件应用 —— 后续还有更多。\n- **📥 多个邮箱账号！** 个人和公司账号？没问题，还有好用的统一收件箱。可连接任何 IMAP 账号。\n- **🔒 收发加密邮件！** 使用超棒的 [Mailvelope](https://mailvelope.com) 浏览器扩展。\n- **🙈 我们没有重复造轮子！** 基于超棒的 [Horde](http://horde.org) 软件库。\n- **📬 想托管您自己的邮件服务器？** 我们不需要重新实现这个功能，因为你们可以搭建 [Mail-in-a-Box](https://mailinabox.email)！",
    "Auto" : "自动",
    "Name" : "姓名",
    "Mail Address" : "邮箱",
    "Password" : "密码",
    "Manual" : "手动",
    "IMAP Settings" : "IMAP 设置",
    "IMAP Host" : "IMAP 主机",
    "IMAP Security" : "IMAP 安全",
    "None" : "无",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP 端口",
    "IMAP User" : "IMAP 用户",
    "IMAP Password" : "IMAP 密码",
    "SMTP Settings" : "SMTP 设置",
    "SMTP Host" : "SMTP 主机",
    "SMTP Security" : "SMTP 安全",
    "SMTP Port" : "SMTP 端口",
    "SMTP User" : "SMTP 用户",
    "SMTP Password" : "SMTP 密码",
    "Save" : "保存",
    "Connect" : "连接",
    "Add mail account" : "添加邮件账号",
    "Use Gravatar and favicon avatars" : "使用 Gravatar 和 favicon 形象",
    "Register as application for mail links" : "注册为邮件链接应用",
    "Keyboard shortcuts" : "键盘快捷方式",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "在寻找加密您邮件的方法吗？安装 Mailvelope 浏览器扩展！",
    "From" : "发件人",
    "Select account" : "选择账号",
    "To" : "收件人",
    "Contact or email address …" : "联系人或邮箱地址...",
    "No contacts found." : "未找到联系人。",
    "Subject" : "主题",
    "Subject …" : "标题...",
    "This message came from a noreply address so your reply will probably not be read." : "标记的消息来自一个无法回复的地址，您的回复可能不会被阅读。",
    "Write message …" : "编写消息...",
    "Saving draft …" : "正在保存草稿 …",
    "Draft saved" : "草稿已保存",
    "Upload attachment" : "上传附件",
    "Add attachment from Files" : "从文件添加附件",
    "Enable formatting" : "启用格式化",
    "Uploading attachments …" : "正在上传附件…",
    "Sending …" : "正在发送…",
    "Error sending your message" : "发送您的消息时出错",
    "Go back" : "后退",
    "Retry" : "重试",
    "Message sent!" : "消息已发送！",
    "Write another message" : "再写一条消息",
    "Send" : "发送",
    "Uploading {percent}% …" : "正在上传 {percent}% …",
    "Choose a file to add as attachment" : "选择文件添加为附件",
    "Writing mode" : "编写模式",
    "Preferred writing mode for new messages and replies." : "编写 新消息 及 回复消息 的偏好模式。",
    "Plain text" : "纯文本",
    "Rich text" : "富文本",
    "No messages in this folder" : "该文件夹内没有消息",
    "Draft: " : "草稿: ",
    "Unfavorite" : "取消收藏",
    "Favorite" : "收藏",
    "Mark read" : "标记为已读",
    "Mark unread" : "标记为未读",
    "Delete" : "删除",
    "Blind copy recipients only" : "仅向收件人发送无信头副本",
    "Report this bug" : "报告此问题",
    "Could not open mailbox" : "无法打开邮箱",
    "Loading messages" : "正在加载消息",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "正在为您的消息建立索引。 对于较大的邮箱，这可能需要更长的时间。",
    "Not found" : "没有找到",
    "to" : "收件人",
    "cc" : "抄送",
    "Reply" : "回复",
    "Reply to sender only" : "只回复发送者",
    "Forward" : "转发",
    "Could not load your message" : "无法加载您的消息",
    "Import into calendar" : "导入到日历",
    "Download attachment" : "下载附件",
    "Save to Files" : "保存到“文件”",
    "Unnamed" : "未命名",
    "Embedded message" : "嵌入式消息",
    "Choose a folder to store the attachment in" : "选择一个文件夹来存储附件",
    "Save all to Files" : "全部保存到文件",
    "Choose a folder to store the attachments in" : "选择附件保存的目录",
    "The images have been blocked to protect your privacy." : "图片已被禁用，以保护您的隐私。",
    "Show images from this\tsender" : "显示此发件人的图片",
    "New message" : "新建消息",
    "Settings" : "设置",
    "Edit account" : "编辑账号",
    "Add folder" : "添加文件夹",
    "Move Up" : "上移",
    "Move down" : "下移",
    "Delete account" : "删除账号",
    "Show all folders" : "显示全部文件夹",
    "Collapse folders" : "折叠文件夹",
    "Mark all as read" : "标记所有为已读",
    "Mark all messages of this folder as read" : "将此文件夹中的所有消息都标记为已读",
    "Add subfolder" : "添加子文件夹",
    "Loading …" : "正在加载...",
    "_{total} message_::_{total} messages_" : ["{total} 条消息"],
    "Could not load your draft" : "无法加载您的草稿",
    "Could not load original message" : "无法加载初始消息",
    "No message selected" : "没有选择消息",
    "Signature" : "签名",
    "A signature is added to the text of new messages and replies." : "签名已加入到 新消息 及 回复消息 的文本中。",
    "Signature …" : "签名...",
    "Save signature" : "保存签名",
    "Import into {calendar}" : "导入到 {calendar}",
    "Event imported into {calendar}" : "事件导入到 {calendar}",
    "Could not create event" : "无法建立事件",
    "Airplane" : "飞机",
    "Reservation {id}" : "预订 {id}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "{flightNr} 航班从 {depAirport} 飞往 {arrAirport}",
    "Train" : "火车",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} 从 {depStation} 到 {arrStation}",
    "Train from {depStation} to {arrStation}" : "火车从 {depStation} 到 {arrStation}",
    "Mail app" : "邮件应用",
    "The mail app allows users to read mails on their IMAP accounts." : "邮件应用允许用户阅读其 IMAP 账号中的邮件。",
    "Email: {email}" : "电子邮件：{email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP: {user} 在 {host}:{port} ({ssl} 加密)",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP: {user} 在 {host}:{port} ({ssl} 加密)",
    "Provision an account for every user" : "为每个用户设置一个账号",
    "General" : "常规",
    "Email address" : "Email 地址",
    "IMAP" : "IMAP",
    "User" : "用户",
    "Host" : "主机",
    "Port" : "端口",
    "SMTP" : "SMTP",
    "Apply and create/update for all users" : "为所有用户应用并 创建 / 更新",
    "Disable and un-provision existing accounts" : "禁用和取消设置现有账号",
    "With the settings above, the app will create account settings in the following way:" : "使用上述设置，该应用将通过以下方式创建账号设置：",
    "Account settings" : "账号设置",
    "Change name" : "更改名称",
    "Mail server" : "邮件服务器",
    "Speed up your Mail experience with these quick shortcuts." : "利用这些快捷方式使您的邮件使用过程更加迅捷",
    "Compose new message" : "撰写新消息",
    "Newer message" : "更新的信息",
    "Older message" : "更早的信息",
    "Toggle star" : "切换星标",
    "Toggle unread" : "切换未读",
    "Search" : "搜索",
    "Refresh" : "刷新",
    "Connect your mail account" : "连接您的邮件账号",
    "Unexpected error during account creation" : "创建账号时发生意外错误",
    "Itinerary for {type} is not supported yet" : "尚不支持 {type} 类型的行程",
    "All" : "全部",
    "Archive" : "归档",
    "Drafts" : "草稿",
    "Favorites" : "收藏",
    "All inboxes" : "所有收件箱",
    "Inbox" : "收件箱",
    "Junk" : "垃圾邮件",
    "Sent" : "已发送",
    "Trash" : "废件箱",
    "Error while sharing file" : "共享文件时出错",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["来自 {from} 的 %n 条新消息"],
    "Nextcloud Mail" : "Nextcloud 邮件",
    "Could not load {tag}{name}{endtag}" : "无法加载 {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "加载 {tag}{name}{endtag} 时出现问题",
    "Could not load the desired message" : "无法加载想要的消息",
    "Could not load the message" : "无法加载该消息",
    "Error loading message" : "载入消息时发生错误",
    "Forwarding to %s" : "转发给 %s",
    "Click here if you are not automatically redirected within the next few seconds." : "如果您在接下来几秒钟内未被自动重定向，请点击此处。",
    "Redirect" : "重定向",
    "The link leads to %s" : "链接指向 %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "如果您不想访问此网页，您可以返回到<a href=\"%s\">邮件</a>应用。",
    "Continue to %s" : "继续 %s"
},
"nplurals=1; plural=0;");
